==> home-library-jcr-1.5.1-20130528.170244-5-sources.jar: org/gcube/portlets/user/homelibrary/jcr/workspace/folder/items/JCRTabularDataLink.java <==
/**
 * 
 */
package org.gcube.portlets.user.homelibrary.jcr.workspace.folder.items;


import javax.jcr.Node;
import javax.jcr.RepositoryException;


import org.gcube.portlets.user.homelibrary.home.exceptions.InternalErrorException;
import org.gcube.portlets.user.homelibrary.home.workspace.folder.FolderItemType;
import org.gcube.portlets.user.homelibrary.home.workspace.folder.items.TabularDataLink;
import org.gcube.portlets.user.homelibrary.jcr.workspace.JCRWorkspace;


/**
 * @author gioia
 *
 */
public class JCRTabularDataLink extends JCRWorkspaceFolderItem implements TabularDataLink {
	
	private static final String NT_CONTENT 		= "nthl:externalResourceLinkContent";
	
	private static final String TABLE_ID = "";
	private static final String TABLE_TEMPLATE = "";
	private static final String PROVENANCE = "";
	private static final String RUNTIME_RESOURCE = "";

	private String tableId;
	private String template;
	private String provenance;
	private String runtimeResource;
	
	public JCRTabularDataLink(JCRWorkspace workspace, Node node)
			throws RepositoryException {
		super(workspace, node);
		
		Node contentNode = node.getNode(CONTENT);
		this.tableId = contentNode.getProperty(TABLE_ID).getString();
		this.template = contentNode.getProperty(TABLE_TEMPLATE).getString();
		this.provenance = contentNode.getProperty(PROVENANCE).getString();
		this.runtimeResource = contentNode.getProperty(RUNTIME_RESOURCE).getString();
		
	}
	
	public JCRTabularDataLink(JCRWorkspace workspace, Node node, String name, String description,
			 String tableId, String template, String provenance, String runtimeResource) throws RepositoryException {
		super(workspace, node, name, description);

		
		Node contentNode = node.addNode(CONTENT, NT_CONTENT); 
		
		contentNode.setProperty(TABLE_ID, tableId);
		contentNode.setProperty(TABLE_TEMPLATE, template);
		contentNode.setProperty(PROVENANCE, provenance);
		contentNode.setProperty(RUNTIME_RESOURCE, runtimeResource);
		
	}

	@Override
	public String getTableId() {
		return tableId;
	}


	@Override
	public String getTemplate() {
		return template;
	}

	@Override
	public String getProvenance() {
		return provenance;
	}

	
	@Override
	public void saveContent(Node node) throws RepositoryException {
		return;
	}

	@Override
	public FolderItemType getFolderItemType() {
		
		return FolderItemType.TABULAR_DATA_LINK;
	}

	@Override
	public long getLength() throws InternalErrorException {
		return 0;
	}

	@Override
	public String getDBRuntimeResource() {
		return runtimeResource;
	}

	@Override
	public String getMimeType() throws InternalErrorException {
		return null;
	}
	
}

==> home-library-jcr-1.6.1-20131007.173427-5-sources.jar: org/gcube/portlets/user/homelibrary/jcr/workspace/folder/items/JCRTabularDataLink.java <==
/**
 * 
 */
package org.gcube.portlets.user.homelibrary.jcr.workspace.folder.items;


import javax.jcr.Node;
import javax.jcr.RepositoryException;


import org.gcube.portlets.user.homelibrary.home.exceptions.InternalErrorException;
import org.gcube.portlets.user.homelibrary.home.workspace.folder.FolderItemType;
import org.gcube.portlets.user.homelibrary.home.workspace.folder.items.TabularDataLink;
import org.gcube.portlets.user.homelibrary.jcr.workspace.JCRWorkspace;


/**
 * @author gioia
 *
 */
public class JCRTabularDataLink extends JCRWorkspaceFolderItem implements TabularDataLink {
	
	private static final String NT_CONTENT 			= "nthl:tabularDataLinkContent";

	private static final String TABLE_ID 			= "hl:tableID";
	private static final String TABLE_TEMPLATE 		= "hl:tableTemplateID";
	private static final String PROVENANCE 			= "hl:provenance";
	private static final String RUNTIME_RESOURCE 	= "hl:runtimeResourceID";
	private static final String OPERATOR 			= "hl:operator";

	private final String tableId;
	private final String template;
	private final Provenance provenance;
	private final String runtimeResource;
	private String operator;
	
	public JCRTabularDataLink(JCRWorkspace workspace, Node node)
			throws RepositoryException {
		super(workspace, node);
		
		Node contentNode = node.getNode(CONTENT);
		this.tableId = contentNode.getProperty(TABLE_ID).getString();
		this.template = contentNode.getProperty(TABLE_TEMPLATE).getString();
		this.provenance =  Provenance.valueOf(contentNode.getProperty(PROVENANCE).getString());
		this.runtimeResource = contentNode.getProperty(RUNTIME_RESOURCE).getString();
		
		if (contentNode.hasProperty(OPERATOR))
			this.operator = contentNode.getProperty(OPERATOR).getString();
		
	}
	
	public JCRTabularDataLink(JCRWorkspace workspace, Node node, String name, String description,
			 String tableId, String template, Provenance provenance, String operator, String runtimeResource) throws RepositoryException {
		super(workspace, node, name, description);

		
		this.tableId = tableId;
		this.template = template;
		this.provenance =  provenance;
		this.runtimeResource = runtimeResource;
		this.operator = operator;
		
		Node contentNode = node.addNode(CONTENT, NT_CONTENT); 
		
		contentNode.setProperty(TABLE_ID, tableId);
		contentNode.setProperty(TABLE_TEMPLATE, template);
		contentNode.setProperty(PROVENANCE, provenance.toString());
		contentNode.setProperty(RUNTIME_RESOURCE, runtimeResource);
		
		if (operator != null)
			contentNode.setProperty(OPERATOR, operator);
		
	}

	@Override
	public String getTableId() {
		return tableId;
	}


	@Override
	public String getTemplate() {
		return template;
	}

	@Override
	public Provenance getProvenance() {
		return provenance;
	}

	
	@Override
	public void saveContent(Node node) throws RepositoryException {
		return;
	}

	@Override
	public FolderItemType getFolderItemType() {
		
		return FolderItemType.TABULAR_DATA_LINK;
	}

	@Override
	public long getLength() throws InternalErrorException {
		return 0;
	}

	@Override
	public String getDBRuntimeResource() {
		return runtimeResource;
	}

	@Override
	public String getMimeType() throws InternalErrorException {
		return null;
	}

	@Override
	public String getOperator() {
		return operator;
	}
	
}
